@@ -1,7 +1,8 @@
 /*
  *  xfce4-taskmanager - very simple taskmanger
  *
- *  Copyright (c) 2005 Johannes Zellner, <webmaster@nebulon.de>
+ *  Copyright (c) 2006  Johannes Zellner <webmaster@nebulon.de>
+ *                2008  Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,13 +29,21 @@
 #include <gtk/gtk.h>
 
 #include "functions.h"
-#include "interface.h"                       
+#include "interface.h"
 
-void on_button1_button_press_event(GtkButton *button, GdkEventButton *event);
-void on_button3_toggled_event(GtkButton *button, GdkEventButton *event);
+
+#include "xfce-taskmanager-linux.h"
+
+void on_preferences(GtkButton *button);
+void on_information(GtkButton *button);
+void on_show_info_toggled(GtkCheckMenuItem *menuitem, gint uid);
 gboolean on_treeview1_button_press_event(GtkButton *button, GdkEventButton *event);
 void on_info1_activate (GtkMenuItem *menuitem,  gpointer user_data);
 void handle_task_menu(GtkWidget *widget, gchar *signal);
+void handle_prio_menu(GtkWidget *widget, gchar *prio);
 void on_show_tasks_toggled (GtkMenuItem *menuitem, gint uid);
+void on_show_cached_as_free_toggled (GtkMenuItem *menuitem, gint uid);
+
+void on_quit(void);
 
 #endif
